@@ -2,7 +2,7 @@
 from unittest import TestCase
 from mock import patch, Mock
 from ..search import SphinxConnector, SphinxSearch, SphinxSnippets
-from ..core.exceptions import SphinxQLSyntaxException, SphinxQLDriverException, ImproperlyConfigured
+from ..core.exceptions import SphinxQLSyntaxException, ImproperlyConfigured
 from ..core.lexemes import Q, Avg, Count
 
 
@@ -12,6 +12,9 @@ class TestSQLConnector(TestCase):
         with self.assertRaises(ImproperlyConfigured):
             SphinxSearch('index').process()
 
+        with self.assertRaises(ImproperlyConfigured):
+            SphinxSnippets('index', ['data'], 'query').process()
+
 
 class TestSQLProcessor(TestCase):
 
@@ -110,23 +113,36 @@ class TestSQLProcessor(TestCase):
         self.assertEqual(c, "SELECT * FROM index WHERE id>=1 AND counter IN (1,5)")
 
         d = self.SphinxSearch('index').filter(Q(id__eq=1, id__gte=5)).get_sxql()
-        self.assertEqual(d, "SELECT *, (id>=5 AND id=1) AS cnd FROM index WHERE cnd>0")
+        d_results = ["SELECT *, (id>=5 AND id=1) AS cnd FROM index WHERE cnd>0",
+                     "SELECT *, (id=1 AND id>=5) AS cnd FROM index WHERE cnd>0"]
+        self.assertIn(d, d_results)
 
         e = (self.SphinxSearch('index').filter(Q(id__eq=1) | Q(id__gte=5))
-                                       .filter(Q(counter__in=[1, 5]) & Q(id__lt=20))
+                                       .filter(Q(counter__lt=42, id__lt=20))
                                        .filter(id__eq=2)
                                        .get_sxql())
-        self.assertEqual(e, "SELECT *, (id=1) OR (id>=5) AND (counter IN (1,5)) AND (id<20) AS cnd FROM index WHERE cnd>0 AND id=2")
+        e_possible_q_orders = ["(id=1) OR (id>=5) AND (counter<42 AND id<20)",
+                               "(id=1) OR (id>=5) AND (id<20, counter<42)"]
+        e_possible_queries = ["SELECT *, {or_q} AS cnd FROM index WHERE cnd>0 AND id=2".format(or_q=or_q) for or_q in e_possible_q_orders]
+        self.assertIn(e, e_possible_queries)
 
-        f = self.SphinxSearch('index').filter(Q(id__eq=1, id__gte=5) & Q(counter__eq=1, counter__gte=100)).get_sxql()
-        self.assertEqual(f, "SELECT *, (id>=5 AND id=1) AND (counter>=100 AND counter=1) AS cnd FROM index WHERE cnd>0")
+        f = self.SphinxSearch('index').filter(~Q(id__eq=1, id__gte=5) & Q(counter__eq=1, counter__gte=100)).get_sxql()
+        f_possible_q_orders = ["(id=1 OR id>=5) AND (counter=1 AND counter>=100)",
+                               "(id=1 OR id>=5) AND (counter>=100 AND counter=1)",
+                               "(id>=5 OR id=1) AND (counter=1 AND counter>=100)",
+                               "(id>=5 OR id=1) AND (counter>=100 AND counter=1)"]
+        f_possible_queries = ["SELECT *, {or_q} AS cnd FROM index WHERE cnd>0".format(or_q=or_q) for or_q in f_possible_q_orders]
+        self.assertIn(f, f_possible_queries)
 
         g = (self.SphinxSearch('index').filter(institute__eq=6506)
                                        .filter(location__eq=1565)
                                        .cluster('location')
                                        .filter(Q(id__eq=1, id__gte=5))
                                        .get_sxql())
-        self.assertEqual(g, "SELECT *, COUNT(*) AS num, (id>=5 AND id=1) AS cnd FROM index WHERE institute=6506 AND location=1565 AND cnd>0 GROUP BY location")
+        g_possible_q_orders = ["(id>=5 AND id=1)", "(id=1 AND id>=5)"]
+        g_possible_queries = ["SELECT *, COUNT(*) AS num, {or_q} AS cnd FROM index WHERE institute=6506 AND location=1565 AND cnd>0 GROUP BY location"
+                              .format(or_q=or_q) for or_q in g_possible_q_orders]
+        self.assertIn(g, g_possible_queries)
 
     def test_match_with_filters(self):
         a = self.SphinxSearch('index').match('Hello').filter(id__gte=1).get_sxql()
@@ -147,8 +163,11 @@ class TestSnippets(TestCase):
         self.assertIsInstance(self.SphinxSearch.Snippets('index', ['only good news'], query='Good News'), SphinxSnippets)
 
     def test_basic(self):
-        query = self.SphinxSearch.Snippets('index', ['only good news', 'news'], query='Good News').get_sxql()
-        self.assertEqual(query, u"CALL SNIPPETS(('only good news', 'news'), 'index', 'Good News')")
+        query_1 = self.SphinxSearch.Snippets('index', ['only good news', 'news'], query='Good News').get_sxql()
+        self.assertEqual(query_1, "CALL SNIPPETS(('only good news', 'news'), 'index', 'Good News')")
+
+        query_2 = self.SphinxSearch.Snippets('index', 'only good news', query='Good News').get_sxql()
+        self.assertEqual(query_2, "CALL SNIPPETS(('only good news'), 'index', 'Good News')")
 
     def test_options(self):
         query = self.SphinxSearch.Snippets('index', ['only good news', 'news'], 'Good News').options(**{'limit': 320})
